#!/usr/bin/python3

import pcbnew
import os
import errno

outFile="./out_script.kicad_pcb"
templateFile="./test2empty.kicad_pcb"
emptyFile="./empty.kicad_pcb"

def removeFile(path,ignoreMissing=1):
  try:
    os.remove(path);
  except OSError as e:
    #in case the error was because the file did not exist we ignore it
    #other errors are raised again , so we don't miss them
    if e.errno != errno.ENOENT or not ignoreMissing:
      raise

removeFile(outFile)
template=pcbnew.LoadBoard(templateFile)

out=pcbnew.LoadBoard(emptyFile)
out.SetFileName(outFile)
out.Save(outFile)

startOffset=[40,40]
dX=90
dY=60
countX=1
countY=1

def getMoves(startOffset,dX,dY,countX=1,countY=1):
  """
    Generator to get the target position of the panel. As wxPoint s
    startOffset should a list of x,y cooridnates in mm
    dX and dY are the distance from one print to the next in the panel in mm
    countX and countY is how many rows / colums the panel has
  """
  start=pcbnew.wxPoint(pcbnew.FromMM(startOffset[0]),pcbnew.FromMM(startOffset[1]))
  for x in range(countX):
    for y in range(countY):
      XMove=x*dX+startOffset[0]
      YMove=y*dY+startOffset[1]
      yield pcbnew.wxPoint(pcbnew.FromMM(XMove),pcbnew.FromMM(YMove))


for target0Pos in getMoves(startOffset,dX,dY,countX=countX,countY=countY):
  print("debug target position",target0Pos)
  for i in range(template.GetAreaCount()):
    item = template.GetArea(i)
    copy= item.Duplicate()
    copy.Move(target0Pos)
    out.Add(copy)
    
  for item in template.GetTracks():
    copy=item.Duplicate()
    copy.Move(target0Pos)
    out.Add(copy)
    
  for item in template.GetModules():
    copy=pcbnew.MODULE(item)
    copy.Move(target0Pos)
    out.Add(copy)
    
  for item in template.GetDrawings():
    copy=item.Duplicate()
    copy.Move(target0Pos)
    out.Add(copy)


#pcbnew.Refresh() #add this to test if that changes anything, it didn't
print("Debug: Will save outFile")
out.Save(outFile)
print("Debug: done")

